@@ -1,23 +1,13 @@
-/***************************************************************************
+/*
+    SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
 
-    Copyright 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 
 #include "vocabularymimedata.h"
 
 #include <KEduVocTranslation>
-#include <KEduVocWordtype>
 
 
 void VocabularyMimeData::setTranslations(const QList<KEduVocTranslation *> &translations)
