@@ -1,23 +1,14 @@
-/***************************************************************************
-    Copyright 2014 Andreas Xavier
-    Copyright 2014 Inge Wallin <inge@lysator.liu.se>
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2014 Andreas Xavier
+    SPDX-FileCopyrightText: 2014 Inge Wallin <inge@lysator.liu.se>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 
 // Own
 #include "collectionwidget.h"
 
 // Parley
-#include "barwidget.h"
 
 // KDE
 #include <KLocalizedString>
@@ -33,7 +24,6 @@
 
 // Parley
 #include "utils.h"
-#include "collection.h"
 
 
 // Size constants for the collection widgets
